import { Component, inject, Input } from '@angular/core';
import { MatInputModule } from '@angular/material/input';
import { MatIconModule } from '@angular/material/icon';
import { MatFormFieldModule } from '@angular/material/form-field';
import { FormControl, ReactiveFormsModule } from '@angular/forms';
import { containsLettersInOrder } from '../../shared/utils/string-compare';
import { MatButtonModule } from '@angular/material/button';
import { MatDialog } from '@angular/material/dialog';
import { HermesClientService } from '../../hermes-client.service';
import { Group } from '../../shared/models/group';
import EventService from '../../shared/services/EventService';
import { PermissionItemComponent } from '../permission-item/permission-item.component';
import { Permission } from '../../shared/models/permission';
import { PermissionItemEditComponent } from '../permission-item-edit/permission-item-edit.component';

@Component({
  selector: 'permission-list',
  imports: [
    MatButtonModule,
    MatFormFieldModule,
    MatIconModule,
    MatInputModule,
    ReactiveFormsModule,
    PermissionItemComponent,
  ],
  templateUrl: './permission-list.component.html',
  styleUrl: './permission-list.component.scss'
})
export class PermissionListComponent {
  @Input({ required: true }) groups: Group[] = [];
  @Input({ alias: 'permissions', required: true }) _permissions: Permission[] = [];
  @Input() group: Group | undefined;

  readonly dialog = inject(MatDialog);
  readonly client = inject(HermesClientService);
  readonly events = inject(EventService);
  readonly searchControl = new FormControl<string>('');

  opened = false;


  add() {
    if (!this.group || this.opened) {
      return;
    }

    this.opened = true;

    const groupId = this.group.id;

    const dialogRef = this.dialog.open(PermissionItemEditComponent, {
      data: { permission: { id: '', user_id: '', group_id: groupId, path: '', allow: null }, group: this.group, groups: [], isNew: true },
    });

    dialogRef.afterClosed().subscribe((permission: Permission) => this.opened = false);
  }

  get permissions() {
    return this._permissions.filter(p => containsLettersInOrder(p.path, this.searchControl.value));
  }

  getGroupById(groupId: string) {
    return this.groups.find(g => g.id == groupId);
  }
}